#!/bin/sh

# make sure executable exists
if [ x"$1" = x ]; then
  echo "usage: $0 program program_args"
  exit 1
fi
if [ ! -x "$1" ]; then
  echo "ERROR: can't find executable: $1"
  exit 1
fi
EXE="$1"
shift

# start in home directory
cd

# make sure display is set
if [ x"$DISPLAY" = x ]; then
  DISPLAY=:0.0
  export DISPLAY
fi

# start X11 if nexessary
lsof | grep 'X11-unix' > /dev/null
if [ "$?" = "1" ]; then
  # use applescript to ensure that it completes before starting ds9)
  osascript -e 'tell application "X11" to activate'
fi

# determine user shell
SH=`finger $USER | grep -i shell | sed 's/.*[sS]hell: *//g' | awk '{print $1}'`
# make sure we have some shell to execute
if [ x"$SH" = x ]; then
  SH="/bin/sh"
fi

# determine shell-based file to source in order to get path
case "$SH" in
    */tcsh)
    if [ -r /etc/csh.cshrc ]; then
      INIT="source /etc/csh.cshrc;"
    fi
    if [ -r ~/.tcshrc ]; then
      INIT="$INIT source ~/.tcshrc;"
    elif [ -r ~/.cshrc ]; then
      INIT="$INIT source ~/.cshrc;"
    fi
    ;;

    */csh)
    if [ -r /etc/csh.cshrc ]; then
      INIT="source /etc/csh.cshrc;"
    fi
    if [ -r ~/.cshrc ]; then
      INIT="$INIT source ~/.cshrc;"
    fi
    ;;

    */bash)
    if [ -r /etc/profile ]; then
      INIT=". /etc/profile;"
    fi
    if [ -r ~/.bash_profile ]; then
      INIT="$INIT . ~/.bash_profile;"
    elif [ -r ~/.bash_login ]; then
      INIT="$INIT . ~/.bash_login;"
    elif [ -r ~/.profile ]; then
      INIT="$INIT . ~/.profile;"
    fi
    ;;

    */sh|*/ksh)
    if [ -r /etc/profile ]; then
      INIT=". /etc/profile;"
    fi
    if [ -r ~/.profile ]; then
      INIT="$INIT . ~/.profile;"
    fi
    ;;

    *)
    ;;

esac

# this is the command we will execute
CMD="$INIT $EXE $@"

# start program using the user's shell
$SH -c "$CMD" &
